@@ -100,7 +100,7 @@ class AiohttpWslinkServer(object):
         port = int(self.config["port"])
         timeout = int(self.config["timeout"])
         handle_signals = self.config["handle_signals"]
-        ssl_context = self.config["ssl"] = None
+        ssl_context = self.config.get("ssl", None)
 
         runner = aiohttp_web.AppRunner(app, handle_signals=handle_signals)
         loop = asyncio.get_event_loop()
